@@ -6,6 +6,7 @@ optDict = {
     'Target': {
         'url': 'string',
         'url_file': 'string',
+        'ports': 'string',
         'poc': 'string',
         'poc_keyword': 'string',
         'configFile': 'string'
@@ -20,8 +21,8 @@ optDict = {
         'agent': 'string',
         'proxy': 'string',
         'proxy_cred': 'string',
-        'timeout': 'string',
-        'retry': 'float',
+        'timeout': 'float',
+        'retry': 'integer',
         'delay': 'string',
         'headers': 'string'
     },
