@@ -6,7 +6,7 @@ import inspect
 from collections import OrderedDict
 
 from requests.exceptions import ConnectTimeout, ConnectionError, HTTPError, TooManyRedirects
-from pocsuite3.lib.core.common import parse_target_url, desensitization, check_port, OrderedSet, get_host_ip
+from pocsuite3.lib.core.common import parse_target_url, mosaic, check_port, OrderedSet, get_host_ip
 from pocsuite3.lib.core.data import conf, logger
 from pocsuite3.lib.core.enums import OUTPUT_STATUS, CUSTOM_LOGGING, ERROR_TYPE_ID, POC_CATEGORY
 from pocsuite3.lib.core.exception import PocsuiteValidationException
@@ -41,7 +41,7 @@ class POCBase(object):
             self.global_options["referer"] = OptString("", "HTTP Referer header value")
             self.global_options["agent"] = OptString("", "HTTP User-Agent header value")
             self.global_options["proxy"] = OptString("", "Use a proxy to connect to the target URL")
-            self.global_options["timeout"] = OptInteger(30, "Seconds to wait before timeout connection (default 30)")
+            self.global_options["timeout"] = OptInteger(10, "Seconds to wait before timeout connection (default 10)")
         else:
             self.global_options["rhost"] = OptString('', require=True)
             self.global_options["rport"] = OptPort('', require=True)
@@ -194,26 +194,26 @@ class POCBase(object):
         except ConnectTimeout as e:
             self.expt = (ERROR_TYPE_ID.CONNECTTIMEOUT, e)
             while conf.retry > 0:
-                logger.debug('POC: {0} timeout, start it over.'.format(self.name))
+                logger.debug('connect target {0} timeout, retry it.'.format(mosaic(target)))
                 try:
                     output = self._execute()
                     break
-                except ConnectTimeout:
-                    logger.debug('POC: {0} time-out retry failed!'.format(self.name))
+                except Exception:
+                    logger.debug('target {0} retry failed!'.format(mosaic(target)))
                 conf.retry -= 1
-            else:
-                msg = "connect target '{0}' failed!".format(desensitization(target) if conf.ppt else target)
+            if output is None:
+                msg = "connect target '{0}' failed!".format(mosaic(target))
                 logger.error(msg)
                 output = Output(self)
 
         except HTTPError as e:
             self.expt = (ERROR_TYPE_ID.HTTPERROR, e)
-            logger.warn('POC: {0} HTTPError occurs, start it over.'.format(self.name))
+            logger.warn('target {0} HTTPError occurs.'.format(mosaic(target)))
             output = Output(self)
 
         except ConnectionError as e:
             self.expt = (ERROR_TYPE_ID.CONNECTIONERROR, e)
-            msg = "connect target '{0}' failed!".format(desensitization(target) if conf.ppt else target)
+            msg = "connect target '{0}' failed!".format(mosaic(target))
             logger.error(msg)
             output = Output(self)
 
@@ -233,10 +233,11 @@ class POCBase(object):
         return output
 
     def _check(self, dork='', allow_redirects=False, return_obj=False, is_http=True, honeypot_check=True):
+        self.url = self.url.rstrip('/')
         u = urlparse(self.url)
         # the port closed
         if u.port and not check_port(u.hostname, u.port):
-            logger.debug(f'{self.url}, the port is closed.')
+            logger.debug(f'{mosaic(self.url)}, the port is closed.')
             return False
 
         if not is_http:
@@ -256,15 +257,20 @@ class POCBase(object):
                 if 'plain HTTP request was sent to HTTPS port' in res.text:
                     self.url = f'https://{netloc}'
                     res = requests.get(self.url, allow_redirects=allow_redirects)
-                    logger.warn(f'auto correct url to: {self.url}')
+                    logger.warn(f'auto correct url to: {mosaic(self.url)}')
                 # another protocol is access ok
                 elif url != self.url:
                     self.url = url
-                    logger.warn(f'auto correct url to: {self.url}')
+                    logger.warn(f'auto correct url to: {mosaic(self.url)}')
                 break
             except requests.ConnectionError:
                 pass
 
+        if not self.url.startswith(self.scheme):
+            self.scheme = 'https' if self.url.startswith('https') else 'http'
+            port = urlparse(self.url).port
+            self.rport = port if port else 443 if self.scheme.startswith('https') else 80
+
         if return_obj:
             return res
 
@@ -315,7 +321,7 @@ class POCBase(object):
             is_honeypot = True
 
         if is_honeypot:
-            logger.warn(f'{self.url} is a honeypot.')
+            logger.warn(f'{mosaic(self.url)} is a honeypot.')
 
         return not is_honeypot
 
@@ -401,12 +407,12 @@ class Output(object):
             for k, v in self.result.items():
                 if isinstance(v, dict):
                     for kk, vv in v.items():
-                        if (kk == "URL" or kk == "IP") and conf.ppt:
-                            vv = desensitization(vv)
+                        if (kk == "URL" or kk == "IP"):
+                            vv = mosaic(vv)
                         logger.log(CUSTOM_LOGGING.SUCCESS, "%s : %s" % (kk, vv))
                 else:
-                    if (k == "URL" or k == "IP") and conf.ppt:
-                        v = desensitization(v)
+                    if (k == "URL" or k == "IP"):
+                        v = mosaic(v)
                     logger.log(CUSTOM_LOGGING.SUCCESS, "%s : %s" % (k, v))
 
     def to_dict(self):
