@@ -35,9 +35,11 @@ def cmd_line_parser(argv=None):
         target = parser.add_argument_group('Target', "At least one of these "
                                                      "options has to be provided to define the target(s)")
         target.add_argument("-u", "--url", dest="url", nargs='+',
-                            help="Target URL (e.g. \"http://www.site.com/vuln.php?id=1\")")
+                            help="Target URL/CIDR (e.g. \"http://www.site.com/vuln.php?id=1\")")
 
-        target.add_argument("-f", "--file", dest="url_file", help="Scan multiple targets given in a textual file")
+        target.add_argument("-f", "--file", dest="url_file",
+                            help="Scan multiple targets given in a textual file (one per line)")
+        target.add_argument("-p", "--ports", dest="ports", help="add additional port to each target (e.g. 8080,8443)")
         target.add_argument("-r", dest="poc", nargs='+', help="Load PoC file from local or remote from seebug website")
         target.add_argument("-k", dest="poc_keyword", help="Filter PoC by keyword, e.g. ecshop")
         target.add_argument("-c", dest="configFile", help="Load options from a configuration INI file")
@@ -60,8 +62,9 @@ def cmd_line_parser(argv=None):
         request.add_argument("--user-agent", dest="agent", help="HTTP User-Agent header value (default random)")
         request.add_argument("--proxy", dest="proxy", help="Use a proxy to connect to the target URL")
         request.add_argument("--proxy-cred", dest="proxy_cred", help="Proxy authentication credentials (name:password)")
-        request.add_argument("--timeout", dest="timeout", help="Seconds to wait before timeout connection (default 30)")
-        request.add_argument("--retry", dest="retry", default=False, help="Time out retrials times")
+        request.add_argument("--timeout", dest="timeout", type=float, default=10,
+                             help="Seconds to wait before timeout connection (default 10)")
+        request.add_argument("--retry", dest="retry", type=int, default=0, help="Time out retrials times (default 0)")
         request.add_argument("--delay", dest="delay", help="Delay between two request of one thread")
         request.add_argument("--headers", dest="headers", help="Extra headers (e.g. \"key1: value1\\nkey2: value2\")")
         # Account options
@@ -124,8 +127,8 @@ def cmd_line_parser(argv=None):
                                   help="Load plugins to execute")
         optimization.add_argument("--pocs-path", dest="pocs_path", action="store", default=None,
                                   help="User defined poc scripts path")
-        optimization.add_argument("--threads", dest="threads", type=int, default=1,
-                                  help="Max number of concurrent network requests (default 1)")
+        optimization.add_argument("--threads", dest="threads", type=int, default=150,
+                                  help="Max number of concurrent network requests (default 150)")
         optimization.add_argument("--batch", dest="batch",
                                   help="Automatically choose defaut choice without asking")
         optimization.add_argument("--requires", dest="check_requires", action="store_true", default=False,
